@@ -418,6 +418,25 @@ def test_scale():
     assert room[1].doors[0].area == model.rooms[0][1].doors[0].area * 2 ** 2
 
 
+def test_generate_exterior_face_grid():
+    """Test the generate_exterior_face_grid method."""
+    room = Room.from_box('ShoeBoxZone', 5, 10, 3)
+    model = Model('TinyHouse', [room])
+    mesh_grid = model.generate_exterior_face_grid(1, face_type='Wall')
+    assert len(mesh_grid.faces) == 60 + 30
+    mesh_grid = model.generate_exterior_face_grid(0.5, face_type='All')
+    assert len(mesh_grid.faces) == 200 + 240 + 120
+
+
+def test_generate_exterior_aperture_grid():
+    """Test the generate_exterior_aperture_grid method."""
+    room = Room.from_box('ShoeBoxZone', 5, 10, 3)
+    room[3].apertures_by_ratio(0.4)
+    model = Model('TinyHouse', [room])
+    mesh_grid = model.generate_exterior_aperture_grid(1)
+    assert len(mesh_grid.faces) != 0
+
+
 def test_apertures_by_ratio():
     """Test the apertures_by_ratio methods."""
     room = Room.from_box('TinyHouseZone', 5, 10, 3)
